intervals_list = [
    {  
        'name': 'Perfect unison',
        'semitones': 0,
        'short': 'P1'
    },
    {  
        'name': 'Minor second',
        'semitones': 1,
        'short': 'm2'
    },
    {  
        'name': 'Major second',
        'semitones': 2,
        'short': 'M2'
    },
    {  
        'name': 'Minor third',
        'semitones': 3,
        'short': 'm3'
    },
    {  
        'name': 'Major third',
        'semitones': 4,
        'short': 'M3'
    },
    {  
        'name': 'Perfect fourth',
        'semitones': 5,
        'short': 'P4'
    },
    {  
        'name': 'Tritone',
        'semitones': 6,
        'short': 'TT'
    },
    {  
        'name': 'Perfect fifth',
        'semitones': 7,
        'short': 'P5'
    },
    {  
        'name': 'Minor sixth',
        'semitones': 8,
        'short': 'm6'
    },
    {  
        'name': 'Major sixth',
        'semitones': 9,
        'short': 'M6'
    },
    {  
        'name': 'Minor seventh',
        'semitones': 10,
        'short': 'm7'
    },
    {  
        'name': 'Major seventh',
        'semitones': 11,
        'short': 'M7'
    },
    {  
        'name': 'Octave',
        'semitones': 12,
        'short': 'P8'
    }
]
